Power analysis for tests on one or two proportions: estimate required sample size, power, or minimum detectable difference.

pamlprop(
  aim = "n",
  mode = "propind",
  propind_p1 = 0.6,
  propind_p2 = 0.5,
  propind_n = 20,
  propind_nratio = 1,
  propone_p1 = 0.6,
  propone_p2 = 0.5,
  propone_n = 50,
  proppaired_p1 = 0.1,
  proppaired_p2 = 0.4,
  proppaired_n = 20,
  power = 0.9,
  sig.level = 0.05,
  alternative = "two.sided",
  plot_contour = FALSE,
  plot_escurve = FALSE,
  plot_ncurve = FALSE,
  plot_log = TRUE,
  plot_palette = "viridis",
  plot_x = "none",
  plot_y = "none",
  plot_custom_labels = FALSE,
  plot_z = "none",
  plot_x_from = 0,
  plot_x_to = 0,
  plot_z_lines = 0,
  plot_z_value = list(),
  plot_to_table = FALSE,
  es_type = "odd",
  explain = FALSE,
  .interface = "jamovi",
  .caller = "proportions"
)

Arguments

aim

.

mode

.

propind_p1

.

propind_p2

.

propind_n

.

propind_nratio

.

propone_p1

.

propone_p2

.

propone_n

.

proppaired_p1

.

proppaired_p2

.

proppaired_n

.

power

.

sig.level

.

alternative

.

plot_contour

.

plot_escurve

.

plot_ncurve

.

plot_log

.

plot_palette

.

plot_x

.

plot_y

.

plot_custom_labels

.

plot_z

.

plot_x_from

.

plot_x_to

.

plot_z_lines

.

plot_z_value

.

plot_to_table

.

es_type

.

explain

add an additional description of the analysis carried out

.interface

Used for internal purposes

.caller

.

Value

A results object containing:

results$introa html
results$issuesa html
results$extrainfoa html
results$powertaba table
results$powerbyesa table
results$plotnotesa html
results$powerContouran image
results$powerEscurvean image
results$powerNcurvean image
results$powerCustoman image
results$customnotesa html
results$customtablea table

Tables can be converted to data frames with asDF or as.data.frame. For example:

results$powertab$asDF

as.data.frame(results$powertab)