Description Usage Arguments Details Value Author(s) References See Also Examples
Generate random sequences of numbers using normal distribution
1 2 |
n |
number of observations. |
mean |
distribution mean |
sd |
standard deviation of the mean |
style |
the style output ("vector", "data.frame") |
ncol |
the number of columns if style == "data.frame" |
This functions generate random numbers based on the nomral distribution
through the function rnorm. It uses the 'mean' and standard deviation of the
mean to generate 'n' random numbers. The user can choose to generate multiple
vectors by setting style == "data.frame".
The function rand returns a a vector or a data.frame with
multiple random numbers.
components:
vector: A numeric vector with n observations
data.frame: A data.frame with n rows and ncol columns. Each
colulm corresponds to one vector with n observations.
Your Full Name
Your refrence goes here.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.