These functions extract all visible tables from a ResultsElement or related classes produced by pamlj and print them in R style.

These functions extract all visible tables from a list of tables produced by pamlj3 and print them in R style.

# S3 method for class 'ResultsElement'
summary(object, ...)

# S3 method for class 'pamlj_list'
summary(object, ...)

# S3 method for class 'jmvrtable'
print(x, ...)

# S3 method for class 'jmvrobj'
print(x, ...)

# S3 method for class 'pamlj_list'
print(x, ...)

Arguments

object

a pamlj results object of the class `pamlj`

...

options passed to print()

x

a pamlj results object of the class `pamlj`

Value

a list of table as data.frame

a list of tables as data.frame

Author

Marcello Gallucci

Examples

obj<-pamlj::pamlcorr(es=.1)
summary(obj)
#> A Priori Power Analysis 
#> 
#>        n  es power sig.level
#> "1" 1046 0.1   0.9      0.05
#> 
#> 
#> Power by Effect Size 
#> 
#>                      es     power                   desc
#> "1"      0 < ρ ≤ 0.0606      ≤50%            Likely miss
#> "2" 0.0606 < ρ ≤ 0.0865 50% – 80% Good chance of missing
#> "3" 0.0865 < ρ ≤ 0.1111 80% – 95%        Probably detect
#> "4"          ρ > 0.1111      ≥95%   Almost surely detect
#> 
#> 
data(fivegroups)
#> Warning: data set ‘fivegroups’ not found
fivegroups$Group<-factor(fivegroups$Group)
#> Error: object 'fivegroups' not found
gmod<-pamlj3::pamlj_lm(
  formula = Score ~Group,
  data = fivegroups)
#> Error in loadNamespace(x): there is no package called ‘pamlj3’

summary(gmod)
#> Error: object 'gmod' not found