pamlprop.RdPower analysis for tests on one or two proportions: estimate required sample size, power, or minimum detectable difference.
pamlprop(
aim = "n",
mode = "propind",
propind_p1 = 0.6,
propind_p2 = 0.5,
propind_n = 20,
propind_nratio = 1,
propone_p1 = 0.6,
propone_p2 = 0.5,
propone_n = 50,
proppaired_p1 = 0.1,
proppaired_p2 = 0.4,
proppaired_n = 20,
power = 0.9,
sig.level = 0.05,
alternative = "two.sided",
plot_contour = FALSE,
plot_escurve = FALSE,
plot_ncurve = FALSE,
plot_log = TRUE,
plot_palette = "viridis",
plot_x = "none",
plot_y = "none",
plot_custom_labels = FALSE,
plot_z = "none",
plot_x_from = 0,
plot_x_to = 0,
plot_z_lines = 0,
plot_z_value = list(),
plot_to_table = FALSE,
es_type = "odd",
explain = FALSE,
.interface = "jamovi",
.caller = "proportions"
).
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
.
add an additional description of the analysis carried out
Used for internal purposes
.
A results object containing:
results$intro | a html | ||||
results$issues | a html | ||||
results$extrainfo | a html | ||||
results$powertab | a table | ||||
results$powerbyes | a table | ||||
results$plotnotes | a html | ||||
results$powerContour | an image | ||||
results$powerEscurve | an image | ||||
results$powerNcurve | an image | ||||
results$powerCustom | an image | ||||
results$customnotes | a html | ||||
results$customtable | a table |
Tables can be converted to data frames with asDF or as.data.frame. For example:
results$powertab$asDF
as.data.frame(results$powertab)