pamlttest.RdPower analysis for one-sample, paired, and independent-samples t-tests: estimate required sample size, power, or minimum detectable effect size.
pamlttest(
aim = "n",
mode = "ttestind",
ttestind_es = 0.5,
ttestind_n = 20,
ttestind_nratio = 1,
ttestpaired_es = 0.5,
ttestpaired_n = 20,
ttestone_es = 0.5,
ttestone_n = 20,
is_equi = FALSE,
equi_limit = 0.1,
power = 0.9,
sig.level = 0.05,
alternative = "two.sided",
plot_contour = FALSE,
plot_escurve = FALSE,
plot_ncurve = FALSE,
plot_log = TRUE,
plot_palette = "viridis",
plot_x = "none",
plot_y = "none",
plot_custom_labels = FALSE,
plot_z = "none",
plot_x_from = 0,
plot_x_to = 0,
plot_z_lines = 0,
plot_z_value = list(),
plot_to_table = FALSE,
explain = FALSE,
.caller = "ttest",
.interface = "jamovi",
ttestind_ttest = "-",
ttestind_ngroup = 0,
ttestind_d = 0,
ttestind_useit = FALSE,
ttestpaired_ttest = "-",
ttestpaired_obsn = 0,
ttestpaired_d = 0,
ttestpaired_useit = FALSE,
ttestpaired_dind = "-",
ttestpaired_r = 0,
ttestpaired_dz = 0,
ttestpaired_d_useit = FALSE,
ttestone_ttest = "-",
ttestone_obsn = 0,
ttestone_d = 0,
ttestone_useit = FALSE
)The aim of the analysis: n for required N, power
for estimated power and es for minimal detectable effect size
.
Expected Cohe's d
Sample size per group
Relative size of the two groups. 1 means group of
equal size, ratio>1 means that one group is ratio times
larger than the other.
Expected Cohe's d_z, defined as the mean difference divided by the standard deviation of the difference score
Expected sample size (number of paires)
Expected Cohe's d
Expected sample size
When TRUE, perform an equivalence test to show that a
true effect is small enough to be considered practically negligible
.
Minimal desired power (1-Beta)
Critical alpha (significance level to be used in the analysis)
Wheather the test is two-tailed (two.sided) or
one-tailed (greater).
.
.
.
.
.
.
.
.
.
.
.
.
.
.
not used in R
.
.
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
not used in R
A results object containing:
results$intro | a html | ||||
results$issues | a html | ||||
results$extrainfo | a html | ||||
results$powertab | a table | ||||
results$powerbyes | a table | ||||
results$plotnotes | a html | ||||
results$powerContour | an image | ||||
results$powerEscurve | an image | ||||
results$powerNcurve | an image | ||||
results$powerCustom | an image | ||||
results$customnotes | a html | ||||
results$customtable | a table |
Tables can be converted to data frames with asDF or as.data.frame. For example:
results$powertab$asDF
as.data.frame(results$powertab)